import 'package:flutter/material.dart';
import 'package:palette_generator/palette_generator.dart';

class GradientBackground extends StatefulWidget {
  const GradientBackground({super.key, required this.image, required this.child});

  final ImageProvider image;
  final Widget child;

  @override
  State<GradientBackground> createState() => _GradientBackgroundState();
}

class _GradientBackgroundState extends State<GradientBackground> {
  List<Color> colorsList = [];
  PaletteGenerator? generator;
  final Color lightVibrant = const Color.fromRGBO(197, 231, 255, 1.0);
  final Color lightMuted = const Color.fromRGBO(88, 130, 159, 1.0);

  @override
  void initState() {
    super.initState();
    getColorPalette();
  }

  Future<void> getColorPalette() async {
    generator = await PaletteGenerator.fromImageProvider(widget.image);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    final List<Color> colors = [generator?.lightMutedColor?.color ?? lightMuted, generator?.lightVibrantColor?.color ?? lightVibrant];
    return Scaffold(
        body: generator == null
            ? const Center(child: CircularProgressIndicator())
            : Container(
                decoration: BoxDecoration(
                    gradient: LinearGradient(begin: Alignment.topRight, end: Alignment.bottomLeft, colors: colors)),
                child: widget.child,
              ));
  }
}
