import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class ImageViewer extends StatelessWidget {
  const ImageViewer(
      {super.key,
      required this.imageProvider,
      this.fit,
      this.radius,
      this.indicatorHeight,
      this.opacity,
      this.alignment,
      this.repeat,
      this.frameLoadedBuilder,
      this.frameLoadingBuilder,
      this.boundaryMargin,
      this.clipBehaviour,
      this.constrained,
      this.maxScale,
      this.minScale,
      this.onInteractionEnd,
      this.onInteractionStart,
      this.onInteractionUpdate,
      this.panEnabled,
      this.scaleEnabled,
      this.transformationController,
      this.width,
      this.height});

  final BorderRadius? radius;
  final BoxFit? fit;
  final double? indicatorHeight;
  final Animation<double>? opacity;
  final ImageRepeat? repeat;
  final Alignment? alignment;
  final ImageFrameBuilder? frameLoadedBuilder;
  final ImageLoadingBuilder? frameLoadingBuilder;
  final ImageProvider imageProvider;
  final EdgeInsets? boundaryMargin;
  final Clip? clipBehaviour;
  final bool? constrained;
  final double? minScale;
  final double? maxScale;
  final GestureScaleEndCallback? onInteractionEnd;
  final GestureScaleStartCallback? onInteractionStart;
  final GestureScaleUpdateCallback? onInteractionUpdate;
  final bool? panEnabled;
  final bool? scaleEnabled;
  final TransformationController? transformationController;
  final double? width;
  final double? height;

  @override
  Widget build(BuildContext context) {
    final brightness = WidgetsBinding.instance.platformDispatcher.platformBrightness;
    bool isDarkMode = brightness == Brightness.dark;
    SystemChrome.setEnabledSystemUIMode(SystemUiMode.immersive);
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitUp,
      DeviceOrientation.portraitDown,
      DeviceOrientation.landscapeLeft,
      DeviceOrientation.landscapeRight
    ]);
    return OrientationBuilder(
      builder: (context, orientation) {
        final isPortrait = orientation == Orientation.portrait;
        return Scaffold(
            backgroundColor: isDarkMode ? Colors.black : Colors.white,
            appBar: AppBar(
                backgroundColor: isDarkMode ? Colors.black : Colors.white,
                leading: IconButton(
                    icon: const Icon(Icons.arrow_back), onPressed: () => Navigator.pop(context), color: isDarkMode ? Colors.white : Colors.grey)),
            body: Center(
              child: ClipRRect(
                  borderRadius: radius ?? BorderRadius.zero,
                  child: InteractiveViewer(
                      transformationController: transformationController,
                      boundaryMargin: boundaryMargin ?? const EdgeInsets.all(6),
                      clipBehavior: clipBehaviour ?? Clip.none,
                      constrained: constrained ?? true,
                      minScale: minScale ?? 0.8,
                      maxScale: maxScale ?? 3,
                      onInteractionEnd: onInteractionEnd,
                      onInteractionStart: onInteractionStart,
                      onInteractionUpdate: onInteractionUpdate,
                      panEnabled: panEnabled ?? true,
                      scaleEnabled: scaleEnabled ?? true,
                      child: Image(
                          image: imageProvider,
                          fit: fit ?? (isPortrait ? BoxFit.fitWidth : BoxFit.fitHeight),
                          width: width ?? MediaQuery.of(context).size.width,
                          height: height ?? MediaQuery.of(context).size.height,
                          opacity: opacity,
                          repeat: repeat ?? ImageRepeat.noRepeat,
                          frameBuilder: frameLoadedBuilder ?? (context, child, frame, wasSynchronouslyLoaded) => child,
                          loadingBuilder: frameLoadingBuilder ??
                              (BuildContext context, Widget child, ImageChunkEvent? loadingProgress) {
                                return loadingProgress == null
                                    ? child
                                    : SizedBox(
                                        height: indicatorHeight ?? MediaQuery.of(context).size.height / 4,
                                        child: const Center(child: CircularProgressIndicator()));
                              }))),
            ));
      }
    );
  }
}
